@@ -7,12 +7,13 @@ import pandas as pd
 
 def derivative(df):
     df = df.iloc[40:]
-    delta = df[["Time", "Unsubtracted Weight"]].diff().dropna()
+    local_df = df.reset_index()
+    delta = local_df[["Time", "Unsubtracted Weight"]].diff().dropna()
     delta["Unsubtracted Weight"] = (
         delta["Unsubtracted Weight"].ewm(span=50).mean().div(delta["Time"])
     )
     delta = (
-        pd.concat([delta, df["Sample Temperature"]], axis=1)
+        pd.concat([delta, local_df["Sample Temperature"]], axis=1)
         .dropna()
         .drop(columns=["Time", "Sample Temperature"], errors="ignore")
     )
@@ -68,11 +69,7 @@ def wl_ext(frame, wavelength):
                 return n if n in jitter_frame.columns else jitter(jitter_frame, n + 1)
 
             wave_list.append(frame[jitter(frame, wl + 1)])
-    extracted_frame = pd.DataFrame(wave_list).transpose().reset_index()
-    extracted_frame["index"] = (
-        extracted_frame["index"].astype(float).map(lambda x: x / 60).round(3)
-    )
-    extracted_frame.rename(columns={"index": "Time"}, inplace=True)
+    extracted_frame = pd.DataFrame(wave_list).transpose()
     return extracted_frame
 
 
@@ -146,8 +143,9 @@ def helper(**kwargs):
 
     for file in data_files:
         data_frame = pd.DataFrame()
+        topic_name, name = naming(file, topic_pattern)
 
-        if method == "IR" and wavelength:
+        if method == "IR":
             data_frame = ir_runner(file, wavelength, rms)
 
         if method == "STA":
@@ -156,14 +154,13 @@ def helper(**kwargs):
         if method == "MS":
             data_frame = ms_runner(file)
 
-        topic_name, name = naming(file, topic_pattern)
-
         if method == "MS":
             ion = os.path.splitext(file.split("\\")[-1])[0]
             name = " ".join([name, "-", ion])
 
         if frame_dictionary.get(topic_name):
             frame_dictionary[topic_name][name] = data_frame
+
         else:
             frame_dictionary[topic_name] = {name: data_frame}
 
@@ -172,17 +169,19 @@ def helper(**kwargs):
 
 def ms_runner(file):
     data_frame = pd.read_table(
-        file, sep="\s+", header=None, names=["Time", "Absorbance"]
+        file, sep="\s+", header=None, names=["Time", "Absorbance"], index_col="Time"
     )
     data_frame["Absorbance"] = data_frame["Absorbance"].ewm(span=5).mean()
+    data_frame = series_normalizer(data_frame)
     return data_frame
 
 
 def sta_runner(baseline, columns_to_use, file):
-    data_frame = pd.read_csv(file, engine="python", usecols=columns_to_use)
-    deriv = derivative(data_frame)
-    percent = percentage(data_frame, ["Unsubtracted Weight"])
-    percent.rename(columns={"Unsubtracted Weight": "Percent Weight"}, inplace=True)
+    data_frame = pd.read_csv(
+        file, engine="python", usecols=columns_to_use, index_col="Time"
+    )
+    sta = percentage(data_frame, ["Unsubtracted Weight"])
+    sta.rename(columns={"Unsubtracted Weight": "Percent Weight"}, inplace=True)
     baseline_frames = baseline_load(baseline, columns_to_use)
     method, isograd, temperature = mit_extract(file)
     isograd = isograd.lower()
@@ -198,8 +197,10 @@ def sta_runner(baseline, columns_to_use, file):
     baseline_corrected.rename(
         columns={"Unsubtracted Heat Flow": "Corrected Heat Flow"}, inplace=True
     )
-    data_frame = pd.concat([data_frame, deriv, percent, baseline_corrected], axis=1)
-    return data_frame
+    dsc = percentage(baseline_corrected, ["Corrected Heat Flow"])
+    dsc.rename(columns={"Corrected Heat Flow": "Percent Heat Flow"}, inplace=True)
+
+    return [sta, dsc]
 
 
 def mit_extract(file):
@@ -210,8 +211,12 @@ def mit_extract(file):
 
 
 def ir_runner(file, wavelength, rms):
+
     if rms:
-        data_frame = pd.read_csv(file, engine="python", header=2).dropna()
+        data_frame = pd.read_csv(file, engine="python", header=2, index_col=0).dropna()
+        if data_frame.index.name == "Time (secs)":
+            data_frame.index = data_frame.index.map(lambda x: round((x / 60), 2))
+        data_frame = series_normalizer(data_frame)
         return data_frame
     data_frame = pd.read_csv(file, engine="python", header=3).dropna().transpose()
     header = data_frame.iloc[0]
@@ -219,10 +224,14 @@ def ir_runner(file, wavelength, rms):
     data_frame = data_frame[1:]
     data_frame.columns = header
     data_frame = wl_ext(data_frame, wavelength)
+    if data_frame.index.name == "Time (secs)":
+        data_frame.index = data_frame.index.map(lambda x: round((x / 60), 2))
+    data_frame = series_normalizer(data_frame)
+
     return data_frame
 
 
-def naming(file, topic_pattern):
+def naming(file, topic_pattern=r"\\(Topic.*?)\\"):
     topic_name = re.search(topic_pattern, file)[1]
     topic_name = topic_name.replace("Topic", "").strip()
     method, isograd, temperature = mit_extract(file)
@@ -231,3 +240,24 @@ def naming(file, topic_pattern):
     else:
         name = " ".join([topic_name, "-", isograd])
     return topic_name, name
+
+
+def series_normalizer(data_frame):
+    data_frame = (data_frame - data_frame.min()) / (data_frame.max() - data_frame.min())
+    return data_frame
+
+
+def asym_peak(t, pars):
+    "from Anal. Chem. 1994, 66, 1294-1301"
+    a0 = pars[0]  # peak area
+    a1 = pars[1]  # elution time
+    a2 = pars[2]  # width of gaussian
+    a3 = pars[3]  # exponential damping term
+    f = (
+        a0
+        / 2
+        / a3
+        * np.exp(a2 ** 2 / 2.0 / a3 ** 2 + (a1 - t) / a3)
+        * (erf((t - a1) / (np.sqrt(2.0) * a2) - a2 / np.sqrt(2.0) / a3) + 1.0)
+    )
+    return f
